@@ -3,7 +3,7 @@
 /*
  *  File-Roller
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "typedefs.h"
 #include "file-list.h"
 
-#define GCONF_NOTIFICATIONS 9
+#define GCONF_NOTIFICATIONS 8
 
 enum {
 	COLUMN_FILE_DATA,
@@ -58,6 +58,12 @@ typedef struct {
 	GFreeFunc       free_func;
 } FRBatchActionDescription;
 
+typedef struct {
+	guint      converting : 1;
+	char      *temp_dir;
+	FRArchive *new_archive;
+} FRConvertData;
+
 typedef struct {
         GtkWidget *      app;
 	GtkWidget *      list_view;
@@ -65,10 +71,9 @@ typedef struct {
 	GtkListStore *   empty_store;
 	GtkWidget *      toolbar;
 	GtkWidget *      statusbar;
-	GtkWidget *      progress;
 
 	GtkWidget *      location_bar;
-	GtkWidget *      location_opt;
+	GtkWidget *      location_entry;
 	GtkWidget *      location_label;
 	GtkWidget *      up_button;
 
@@ -112,10 +117,15 @@ typedef struct {
 
 	VisitDirHandle  *vd_handle;
 
+	FRConvertData    convert_data;
+
+	gboolean         stoppable;
+
 	/* Menu items. */
 
 	GtkWidget *      mitem_new_archive;
 	GtkWidget *      mitem_open_archive;
+	GtkWidget *      mitem_save_as_archive;
 	GtkWidget *      mitem_close;
 	GtkWidget *      mitem_recents_menu;
 
@@ -125,6 +135,9 @@ typedef struct {
 	GtkWidget *      mitem_rename_archive;
 	GtkWidget *      mitem_delete_archive;
 
+	GtkWidget *      mitem_select_all;
+	GtkWidget *      mitem_unselect_all;
+
 	GtkWidget *      mitem_view_toolbar;
 	GtkWidget *      mitem_view_statusbar;
 	GtkWidget *      mitem_view_flat;
@@ -174,23 +187,28 @@ typedef struct {
 					 * too .*/
 
 	GList *  dropped_file_list;     /* the list of dropped files. */
-	gboolean add_dropped_files;     /* whether we must add dropped files
+	gboolean add_after_creation;    /* whether we must add dropped files
 					 * after creating an archive. */
+	gboolean add_after_opening;     /* whether we must add dropped files
+					 * after opening an archive. Used in 
+					 * batch mode to avoid unnecessary 
+					 * archive loading. */
+
 	gboolean adding_dropped_files;  /* whether we are adding dropped 
 					 * files. */
 	gboolean update_dropped_files;  /* the update flag of the add 
 					 * operation.  */
 
-	/* batch mode data */
+	/* progress dialog data */
 
-	GtkWidget *batch_win;         /* Window to show when in batch mode. */
-	GtkWidget *batch_action_lbl;      
-	GtkWidget *batch_message_lbl;
-	GtkWidget *batch_quit_button;
-	GtkWidget *batch_help_button;
-	GtkWidget *batch_image;
-       
-	GdkPixbuf *batch_icon;
+	GtkWidget *progress_dialog;
+	GtkWidget *pd_message;
+	GtkWidget *pd_progress_bar;
+	gboolean   progress_pulse;
+	guint      progress_timeout;  /* Timeout to display the progress dialog. */
+	guint      hide_progress_timeout;  /* Timeout to hide the progress dialog. */
+
+	/* batch mode data */
 
 	gboolean   batch_mode;          /* whether we are in a non interactive
 					 * mode. */
@@ -206,42 +224,66 @@ typedef struct {
 
 FRWindow * window_new                       ();
 
-void       window_close                     (FRWindow   *window);
+void       window_close                     (FRWindow      *window);
 
 /* archive operations */
 
-void       window_archive_new               (FRWindow   *window, 
-					     const char *filename);
+void       window_archive_new               (FRWindow      *window, 
+					     const char    *filename);
 
-void       window_archive_open              (FRWindow   *window, 
-					     const char *filename);
+void       window_archive_open              (FRWindow      *window, 
+					     const char    *filename);
 
-void       window_archive_reload            (FRWindow   *window);
+void       window_archive_save_as           (FRWindow      *window, 
+					     const char    *filename);
 
-void       window_archive_rename            (FRWindow   *window, 
-					     const char *filename);
+void       window_archive_reload            (FRWindow      *window);
 
-void       window_archive_add_files         (FRWindow   *window,
-					     GList      *file_list,
-					     gboolean    update);
+void       window_archive_rename            (FRWindow      *window, 
+					     const char    *filename);
 
-void       window_archive_extract           (FRWindow   *window,
-					     GList      *file_list,
-					     const char *extract_to_dir,
-					     gboolean    skip_older,
-					     gboolean    overwrite,
-					     gboolean    junk_paths,
-					     const char *password);
+void       window_archive_add_files         (FRWindow      *window,
+					     GList         *file_list,
+					     gboolean       update);
 
-void       window_archive_close             (FRWindow   *window);
+void       window_archive_add_with_wildcard (FRWindow      *window,
+					     const char    *include_files,
+					     const char    *exclude_files,
+					     const char    *base_dir,
+					     gboolean       update,
+					     gboolean       recursive,
+					     gboolean       follow_links,
+					     gboolean       same_fs,
+					     gboolean       no_backup_files,
+					     gboolean       no_dot_files,
+					     gboolean       ignore_case,
+					     const char    *password,
+					     FRCompression  compression);
 
-void       window_set_password              (FRWindow   *window,
-					     const char *password);
+void       window_archive_add_directory     (FRWindow      *window,
+					     const char    *directory,
+					     const char    *base_dir,
+					     gboolean       update,
+					     const char    *password,
+					     FRCompression  compression);
+
+void       window_archive_extract           (FRWindow      *window,
+					     GList         *file_list,
+					     const char    *extract_to_dir,
+					     gboolean       skip_older,
+					     gboolean       overwrite,
+					     gboolean       junk_paths,
+					     const char    *password);
+
+void       window_archive_close             (FRWindow      *window);
+
+void       window_set_password              (FRWindow      *window,
+					     const char    *password);
 
 /**/
 
 void       window_go_to_location            (FRWindow       *window, 
-					     char           *path);
+					     const char     *path);
 
 void       window_go_up_one_level           (FRWindow       *window);
 
@@ -269,7 +311,8 @@ void       window_stop_activity_mode        (FRWindow    *window);
 
 /**/
 
-void       window_view_last_output          (FRWindow *window); 
+void       window_view_last_output          (FRWindow *window,
+					     const char *title); 
 
 void       window_view_file                 (FRWindow *window, 
 					     char     *file);
@@ -336,4 +379,9 @@ void       window_archive__open_add           (FRWindow      *window,
 
 void       window_archive__close              (FRWindow      *window);
 
+
+/**/
+
+void       window_convert_data_free           (FRWindow *window);
+
 #endif /* FR_WINDOW_H */
